#####################################
Installing the software
#####################################

Fracridge is available in two popular programming languages: MATLAB (tm) and
Python.

MATLAB
=======

Download the recent release of the software `here <https://github.com/nrdg/fracridge/releases>`_,
extract the files and place them in a folder of your choosing. Then, direct MATLAB
to include the ``matlab`` folder in the top-level folder of the extracted
archive in its path.


Python
=======

To install the released version of the software, you can use the Python ``pip``
package manager. In a shell command line issue::

    pip install fracridge

This should download and install the software for your use.

Alternatively, if you would like to download the source code, or install the
bleeding edge of recent developments, To install from source, issue::

    git clone https://github.com/nrdg/fracridge
    cd fracridge
    pip install .


To see how to use the installed software, please read the `user guide <user_guide.html>`_
and read the `examples <auto_examples/index.html>`_
